Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7609)

Unified Diff: chrome/browser/worker_host/worker_process_host.cc

Issue 6338002: net: Remove typedef net::URLRequestContext URLRequestContext; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: for real Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/worker_host/worker_process_host.cc
diff --git a/chrome/browser/worker_host/worker_process_host.cc b/chrome/browser/worker_host/worker_process_host.cc
index 2006e2f3b961536344455ed4e3bd0e41d6180edc..af13f2e13cd3c8c294a90aca30e041daa19bdf7f 100644
--- a/chrome/browser/worker_host/worker_process_host.cc
+++ b/chrome/browser/worker_host/worker_process_host.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2009 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -44,23 +44,23 @@
namespace {
// Helper class that we pass to SocketStreamDispatcherHost so that it can find
// the right URLRequestContext for a request.
class URLRequestContextOverride
: public ResourceMessageFilter::URLRequestContextOverride {
public:
explicit URLRequestContextOverride(
- URLRequestContext* url_request_context)
+ net::URLRequestContext* url_request_context)
: url_request_context_(url_request_context) {
}
virtual ~URLRequestContextOverride() {}
- virtual URLRequestContext* GetRequestContext(
+ virtual net::URLRequestContext* GetRequestContext(
uint32 request_id, ResourceType::Type resource_type) {
return url_request_context_;
}
private:
- URLRequestContext* url_request_context_;
+ net::URLRequestContext* url_request_context_;
};
} // namespace
@@ -44,23 +44,23 @@
namespace {
// Helper class that we pass to SocketStreamDispatcherHost so that it can find
-// the right URLRequestContext for a request.
+// the right net::URLRequestContext for a request.
class URLRequestContextOverride
: public ResourceMessageFilter::URLRequestContextOverride {

Powered by Google App Engine
This is Rietveld 408576698